@@ -3,23 +3,18 @@
 // DESCRIPTION: Verilator: pre-C++11 replacements for std::unordered_set
 //                         and std::unordered_map.
 //
-// Code available from: http://www.veripool.org/verilator
+// Code available from: https://verilator.org
 //
 //*************************************************************************
 //
-// Copyright 2003-2018 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
-
 //*************************************************************************
 // This file has clones of the std::unordered_set and std::unordered_map
 // hash table types. They are here so that Verilator can use hash tables
@@ -39,7 +34,6 @@
 #ifndef _V3_UNORDERED_SET_MAP_H_
 #define _V3_UNORDERED_SET_MAP_H_
 
-#include "verilated_config.h"
 #include "verilatedos.h"
 
 #include <list>
@@ -115,7 +109,7 @@ class vl_unordered_set {
 public:
     // TYPES
     typedef std::list<T_Key> Bucket;
-    enum RehashType {GROW, SHRINK};
+    enum RehashType { GROW, SHRINK };
 
     template <class KK, class VV,
               class HH, class EQ> friend class vl_unordered_map;
@@ -123,9 +117,9 @@ public:
     class iterator {
     protected:
         // MEMBERS
-        size_t m_bucketIdx; //  Bucket this iterator points into.
-        typename Bucket::iterator m_bit; //  Bucket-local iterator.
-        const vl_unordered_set* m_setp;  //  The containing set.
+        size_t m_bucketIdx;  //  Bucket this iterator points into
+        typename Bucket::iterator m_bit;  // Bucket-local iterator
+        const vl_unordered_set* m_setp;  // The containing set
 
     public:
         // CONSTRUCTORS
@@ -153,7 +147,7 @@ public:
             return (!this->operator==(other));
         }
         void advanceUntilValid() {
-            while (1) {
+            while (true) {
                 if (m_bit != m_setp->m_bucketsp[m_bucketIdx].end()) {
                     // Valid iterator in this bucket; we're done.
                     return;
@@ -198,7 +192,7 @@ public:
         , m_log2Buckets(initLog2Buckets())
         , m_bucketsp(NULL)
         , m_hash()
-        , m_equal() { }
+        , m_equal() {}
 
     vl_unordered_set(const vl_unordered_set& other)
         : m_numElements(other.m_numElements)
@@ -214,7 +208,7 @@ public:
         }
     }
     ~vl_unordered_set() {
-        delete [] m_bucketsp; VL_DANGLING(m_bucketsp);
+        VL_DO_DANGLING(delete [] m_bucketsp, m_bucketsp);
     }
 
     vl_unordered_set& operator=(const vl_unordered_set& other) {
@@ -318,7 +312,7 @@ public:
         return find_internal(key, bucketIdx);
     }
 
-    std::pair<iterator, bool> insert(const T_Key &val) {
+    std::pair<iterator, bool> insert(const T_Key& val) {
         size_t bucketIdx;
         iterator existIt = find_internal(val, bucketIdx);
         if (existIt != end()) {
@@ -354,7 +348,7 @@ public:
         return next_it;
     }
 
-    size_t erase(const T_Key &key) {
+    size_t erase(const T_Key& key) {
         size_t bucketIdx;
         iterator it = find_internal(key, bucketIdx);
         if (it != end()) {
@@ -374,7 +368,7 @@ public:
 
     void clear() {
         if (m_bucketsp) {
-            delete [] m_bucketsp;
+            delete[] m_bucketsp;
             m_bucketsp = NULL;
         }
         m_numElements = 0;
@@ -418,7 +412,7 @@ private:
         size_t new_num_buckets = VL_ULL(1) << new_log2Buckets;
         Bucket* new_bucketsp = new Bucket[new_num_buckets];
 
-        for (size_t i=0; i<numBuckets(); i++) {
+        for (size_t i = 0; i < numBuckets(); i++) {
             while (!m_bucketsp[i].empty()) {
                 typename Bucket::iterator bit = m_bucketsp[i].begin();
                 size_t hash = m_hash.operator()(*bit);
@@ -470,7 +464,7 @@ private:
 
     // MEMBERS
     typedef vl_unordered_set<KeyValPair, KeyHash, KeyEqual> MapSet;
-    MapSet m_set;   //  Wrap this vl_unordered_set which holds all state.
+    MapSet m_set;  // Wrap this vl_unordered_set which holds all state.
 
 public:
     // CONSTRUCTORS
